============
 zope.index
============

.. image:: https://img.shields.io/pypi/v/zope.index.svg
        :target: https://pypi.python.org/pypi/zope.index/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.index.svg
        :target: https://pypi.org/project/zope.index/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/zope.index/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/zope.index/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.index/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.index?branch=master

.. image:: https://readthedocs.org/projects/zopeindex/badge/?version=latest
        :target: https://zopeindex.readthedocs.org/en/latest/
        :alt: Documentation Status

The ``zope.index`` package provides several indices for the Zope
catalog.  These include:

* a field index (for indexing orderable values),

* a keyword index,

* a topic index,

* a text index (with support for lexicon, splitter, normalizer, etc.)
